import { HeaderType, ResolveUrlConfigType, EndpointsType, HttpClientType, ResponseType, RequestConfigType } from '../types/HttpClients.types';
/**
 * This class handles the http requests using axios
 * @version 1.0.0
 * @author Alejandro <alejandro.devop@gmail.com>
 */
declare class HttpClient {
    /** This are the app headers, can be modified using the setter function */
    private headers;
    /** Here's where the client stores the requests send */
    private requestsLog;
    /** Flag to control if the application should be logged */
    private readonly log;
    /** Url to make the request */
    private readonly server;
    /** The endpoints or paths to make the requests */
    private endpoints;
    private readonly onRequestDone;
    constructor(options?: HttpClientType);
    /**
     * Function to get the client headers
     */
    getHeaders(): HeaderType;
    /**
     * Function to get the client endpoints
     */
    getEndpoints(): EndpointsType;
    /**
     * Function to get the client server url
     */
    getServer(): string | undefined;
    /**
     * Function to update the client properties
     * auth: Adds a header to control the authorization
     * @param properties
     */
    setProperties(properties: {
        [key: string]: string;
    }): void;
    /**
     * Function to extract paths from the endpoints map
     * @param path
     * @param options
     */
    resolvePath(path: string, options?: ResolveUrlConfigType): string;
    /**
     * Function to execute any kind of request
     * @param path
     * @param options
     */
    doRequest(path: string, options?: ResolveUrlConfigType & RequestConfigType): Promise<ResponseType>;
    private logRequest;
    /**
     * Function to execute a GET request
     * @param path
     * @param options
     */
    doGet(path: string, options?: ResolveUrlConfigType & RequestConfigType): Promise<any>;
    /**
     * Function to execute a POST request
     * @param path
     * @param options
     */
    doPost(path: string, options?: ResolveUrlConfigType & RequestConfigType): Promise<any>;
    /**
     * Function to execute a PATCH request
     * @param path
     * @param options
     */
    doPatch(path: string, options?: ResolveUrlConfigType & RequestConfigType): Promise<any>;
    /**
     * Function to execute a PUT
     * @param path
     * @param options
     */
    doPut(path: string, options?: ResolveUrlConfigType & RequestConfigType): Promise<any>;
    /**
     * Function to execute a Delete Request
     * @param path
     * @param options
     */
    doDelete(path: string, options?: ResolveUrlConfigType & RequestConfigType): Promise<any>;
    /**
     * Function to retrieve the application requests log
     */
    getLog(): {
        headers?: HeaderType | undefined;
        method?: string | undefined;
        url?: string | undefined;
        response?: any;
        status?: any;
    }[];
    setEndpoints(endpoints: EndpointsType): void;
}
export default HttpClient;
