import { RequestConfigType, ResponseType, ResolveUrlConfigType } from "../types/HttpClients.types";
declare type ConfigOverrideType = RequestConfigType & ResolveUrlConfigType;
declare type DefaultConfigType = ConfigOverrideType & {
    lazy?: boolean;
};
declare type Normal = {
    loading: boolean;
    data?: ResponseType;
};
declare type Lazy = [((c: ConfigOverrideType) => Promise<ResponseType>), boolean];
/**
 * Hook to execute get Requests, if you want to execute it lazy passed the flag lazy to true
 * if lazy it will return an array, first position the getter function which will be a promise, the second
 * position it's the loading state
 * otherwise the hook will return an object, data position it's the response, and the loading position represents
 * the loading state, the request will be triggered on Mount
 * @author Alejandro <alejandro.devop@gmail.com>
 * @version 1.0.0
 * @param path
 * @param config
 * @param lazy
 */
declare const useGet: <T extends boolean, R = T extends true ? Lazy : Normal>(path: string, config?: DefaultConfigType | undefined, lazy?: T | undefined) => R;
export default useGet;
